@@ -1,7 +1,7 @@
 package Perinci::Access::Lite;
 
-our $DATE = '2014-12-31'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2015-01-22'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -95,8 +95,14 @@ sub request {
             $meta = Perinci::Sub::Normalize::normalize_function_metadata($meta);
             return [200, "OK ($action)", $meta] if $action eq 'meta';
 
+            # form args (and add special args)
+            my $args = { %{$extra->{args} // {}} }; # shallow copy
+            if ($meta->{features} && $meta->{features}{progress}) {
+                require Progress::Any;
+                $args->{-progress} = Progress::Any->get_indicator;
+            }
+
             # convert args
-            my $args = $extra->{args} // {};
             my $aa = $meta->{args_as} // 'hash';
             my @args;
             if ($aa =~ /array/) {
@@ -196,7 +202,7 @@ Perinci::Access::Lite - A lightweight Riap client library
 
 =head1 VERSION
 
-This document describes version 0.08 of Perinci::Access::Lite (from Perl distribution Perinci-Access-Lite), released on 2015-12-31.
+This document describes version 0.09 of Perinci::Access::Lite (from Perl distribution Perinci-Access-Lite), released on 2015-01-22.
 
 =head1 DESCRIPTION
 
@@ -285,7 +291,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
